Breakpoint<BreakpointId extends Enum> class abstract

Implemented types
Implementers
Annotations

Constructors

Breakpoint({required BreakpointId id, required double minWidth})
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
id → BreakpointId
final
minWidth → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

compareTo(Breakpoint<BreakpointId>? other) → int
Compares this object to another object.
override
eq(Breakpoint<BreakpointId>? other) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator <(Breakpoint<BreakpointId>? other) → bool
operator <=(Breakpoint<BreakpointId>? other) → bool
operator ==(Object other) → bool
The equality operator.
override
operator >(Breakpoint<BreakpointId>? other) → bool
operator >=(Breakpoint<BreakpointId>? other) → bool