LayoutFormat class

Annotations

Constructors

LayoutFormat({required int columns, required double gutter, required double leftMargin, required double topMargin, required double rightMargin, required double bottomMargin, LayoutModule module = const LayoutModule(baseline: 0, rows: 1, gutter: 0)})
const

Properties

bottomMargin → double
final
columns → int
final
gutter → double
final
hashCode → int
The hash code for this object.
no setteroverride
leftMargin → double
final
margins → EdgeInsets
no setter
module → LayoutModule
final
rightMargin → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topMargin → double
final

Methods

bodyHeight(double containerHeight) → double
Returns the height of body region, which doesn't contain margins.
bodySize(Size containerSize) → Size
bodyWidth(double containerWidth) → double
Returns the width of body region, which doesn't contain margins.
columnWidth(double containerWidth) → double
copy({int? columns, double? gutter, double? leftMargin, double? rightMargin, double? topMargin, double? bottomMargin, LayoutModule? module}) → LayoutFormat
modules(double containerHeight) → int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
regionHeight([int modules = 1]) → double
regionWidth(int columns, double containerWidth) → double
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override